@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2018 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -24,7 +24,7 @@
  *
  \par
  * Each pipe node has a data push function, and a data request function.
- * This limits flexability - the data flow is no longer assembled at each
+ * This limits flexibility - the data flow is no longer assembled at each
  * step.
  *
  \par
@@ -61,7 +61,7 @@
  \par
  * No data member may hold a reference to it's stream node.
  * The stream guarantees that DETACH will be called before
- * freeing the node, alowing data members to cleanup.
+ * freeing the node, allowing data members to cleanup.
  *
  \par
  * If a node's data holds a reference to something that needs to
@@ -78,13 +78,13 @@
    return;
  \endcode
  *
- \todo rather than each node undeleting the next, have a clientStreamDelete that walks the list.
+ * TODO: rather than each node undeleting the next, have a clientStreamDelete that walks the list.
  */
 
 CBDATA_CLASS_INIT(clientStreamNode);
 
 clientStreamNode::clientStreamNode(CSR * aReadfunc, CSCB * aCallback, CSD * aDetach, CSS * aStatus, ClientStreamData aData) :
-    head(NULL),
+    head(nullptr),
     readfunc(aReadfunc),
     callback(aCallback),
     detach(aDetach),
@@ -97,7 +97,7 @@ clientStreamNode::~clientStreamNode()
     debugs(87, 3, "Freeing clientStreamNode " << this);
 
     removeFromStream();
-    data = NULL;
+    data = nullptr;
 }
 
 /**
@@ -113,10 +113,10 @@ clientStreamInit(dlink_list * list, CSR * func, CSD * rdetach, CSS * readstatus,
                  ClientStreamData readdata, CSCB * callback, CSD * cdetach, ClientStreamData callbackdata,
                  StoreIOBuffer tailBuffer)
 {
-    clientStreamNode *temp = new clientStreamNode(func, NULL, rdetach, readstatus, readdata);
+    clientStreamNode *temp = new clientStreamNode(func, nullptr, rdetach, readstatus, readdata);
     dlinkAdd(cbdataReference(temp), &temp->node, list);
     temp->head = list;
-    clientStreamInsertHead(list, NULL, callback, cdetach, NULL, callbackdata);
+    clientStreamInsertHead(list, nullptr, callback, cdetach, nullptr, callbackdata);
     temp = (clientStreamNode *)list->tail->data;
     temp->readBuffer = tailBuffer;
 }
@@ -132,7 +132,7 @@ clientStreamInsertHead(dlink_list * list, CSR * func, CSCB * callback,
                        CSD * detach, CSS * status, ClientStreamData data)
 {
     /* test preconditions */
-    assert(list != NULL);
+    assert(list != nullptr);
     assert(list->head);
     clientStreamNode *temp = new clientStreamNode(func, callback, detach, status, data);
     temp->head = list;
@@ -194,11 +194,11 @@ clientStreamDetach(clientStreamNode * thisObject, ClientHttpRequest * http)
 {
     clientStreamNode *temp = thisObject;
 
-    assert(thisObject->node.next == NULL);
+    assert(thisObject->node.next == nullptr);
     debugs(87, 3, "clientStreamDetach: Detaching node " << thisObject);
     /* And clean up thisObject node */
     /* ESI TODO: push refcount class through to head */
-    clientStreamNode *prev = NULL;
+    clientStreamNode *prev = nullptr;
 
     if (thisObject->prev())
         prev = cbdataReference(thisObject->prev());
@@ -209,7 +209,7 @@ clientStreamDetach(clientStreamNode * thisObject, ClientHttpRequest * http)
 
     delete thisObject;
 
-    /* and tell the prev that the detach has occured */
+    /* and tell the prev that the detach has occurred */
     /*
      * We do it in thisObject order so that the detaching node is always
      * at the end of the list
@@ -237,8 +237,8 @@ clientStreamAbort(clientStreamNode * thisObject, ClientHttpRequest * http)
 {
     dlink_list *list;
 
-    assert(thisObject != NULL);
-    assert(http != NULL);
+    assert(thisObject != nullptr);
+    assert(http != nullptr);
     list = thisObject->head;
     debugs(87, 3, "clientStreamAbort: Aborting stream with tail " << list->tail);
 
@@ -269,7 +269,7 @@ clientStreamNode::removeFromStream()
     if (head)
         dlinkDelete(&node, head);
 
-    head = NULL;
+    head = nullptr;
 }
 
 clientStreamNode *
@@ -278,7 +278,7 @@ clientStreamNode::prev() const
     if (node.prev)
         return (clientStreamNode *)node.prev->data;
     else
-        return NULL;
+        return nullptr;
 }
 
 clientStreamNode *
@@ -287,6 +287,6 @@ clientStreamNode::next() const
     if (node.next)
         return (clientStreamNode *)node.next->data;
     else
-        return NULL;
+        return nullptr;
 }
 
